==> seedsui-react-5.5.91.tgz: package/lib/InputDate/InputDateRangePopover.js <==
var _excluded = ["rangeProps", "value", "type", "startInputDateProps", "endInputDateProps", "onChange", "onClick", "children", "dateRangePopoverProps"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeDate.js和PrototypeString.js
import React, { useState, Fragment, forwardRef, useRef, useImperativeHandle } from 'react';
import InputText from "./../InputText";
import DateRangePopover from "./../DateRangePopover";
import helper from "./../DateRangePopover/helper";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var InputDateRange = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$rangeProps = _ref.rangeProps,
      rangeProps = _ref$rangeProps === void 0 ? {
    // 标题
    caption: '',
    // 分割线
    separator: ''
  } : _ref$rangeProps,
      value = _ref.value,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'date-range-popover' : _ref$type,
      _ref$startInputDatePr = _ref.startInputDateProps,
      startInputDateProps = _ref$startInputDatePr === void 0 ? {} : _ref$startInputDatePr,
      _ref$endInputDateProp = _ref.endInputDateProps,
      endInputDateProps = _ref$endInputDateProp === void 0 ? {} : _ref$endInputDateProp,
      onChange = _ref.onChange,
      onClick = _ref.onClick,
      children = _ref.children,
      _ref$dateRangePopover = _ref.dateRangePopoverProps,
      dateRangePopoverProps = _ref$dateRangePopover === void 0 ? {} : _ref$dateRangePopover,
      others = _objectWithoutProperties(_ref, _excluded);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      rangeVisible = _useState2[0],
      setRangeVisible = _useState2[1];

  var inputTextRef = useRef(null);
  useImperativeHandle(ref, function () {
    return inputTextRef.current;
  }); // 类型修改

  type = type.replace('-range-popover', ''); // 开始和结束时间

  var start = null;
  var end = null;

  if (Array.isArray(value) && value.length === 2) {
    start = value[0];
    end = value[1];
  }

  var displayValue = ''; // 允许仅选中开始或者结束

  if ((start || end) && (typeof start === 'string' || typeof end === 'string')) {
    displayValue = "".concat(start || '').concat(rangeProps.separator || '~').concat(end || '');
  }

  if (start && end && typeof start === 'string' && typeof end === 'string') {
    displayValue = helper.getDateName(start, end);
  } // 点击文本框


  function handleClickInput() {
    if (onClick) onClick.apply(void 0, arguments);
    if (others.readOnly) return;
    setRangeVisible(true);
  } // 开始时间和结束时间


  function handleChange(e, value) {
    setRangeVisible(false);
    if (inputTextRef.current) e.currentTarget = inputTextRef.current;

    if (onChange) {
      onChange(e, value);
    }
  }

  return /*#__PURE__*/_jsxs(Fragment, {
    children: [children && /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
      ref: inputTextRef
    }, others), {}, {
      onClick: handleClickInput,
      children: children
    })), !children && /*#__PURE__*/_jsx(InputText, _objectSpread(_objectSpread({
      ref: inputTextRef
    }, others), {}, {
      value: displayValue,
      type: "text",
      readOnly: true,
      onClick: handleClickInput
    })), /*#__PURE__*/_jsx(DateRangePopover, _objectSpread(_objectSpread({}, dateRangePopoverProps), {}, {
      caption: rangeProps.caption,
      show: rangeVisible,
      startInputDateProps: startInputDateProps,
      endInputDateProps: endInputDateProps,
      value: value,
      onChange: handleChange,
      onVisibleChange: setRangeVisible
    }))]
  });
});
export default InputDateRange;

==> seedsui-react-5.5.92.tgz: package/lib/InputDate/InputDateRangePopover.js <==
var _excluded = ["rangeProps", "value", "type", "startInputDateProps", "endInputDateProps", "onChange", "onClick", "children", "dateRangePopoverProps"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeDate.js和PrototypeString.js
import React, { useState, Fragment, forwardRef, useRef, useImperativeHandle } from 'react';
import InputText from "./../InputText";
import DateRangePopover from "./../DateRangePopover";
import helper from "./../DateRangePopover/helper";
var InputDateRange = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$rangeProps = _ref.rangeProps,
      rangeProps = _ref$rangeProps === void 0 ? {
    // 标题
    caption: '',
    // 分割线
    separator: ''
  } : _ref$rangeProps,
      value = _ref.value,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'date-range-popover' : _ref$type,
      _ref$startInputDatePr = _ref.startInputDateProps,
      startInputDateProps = _ref$startInputDatePr === void 0 ? {} : _ref$startInputDatePr,
      _ref$endInputDateProp = _ref.endInputDateProps,
      endInputDateProps = _ref$endInputDateProp === void 0 ? {} : _ref$endInputDateProp,
      onChange = _ref.onChange,
      onClick = _ref.onClick,
      children = _ref.children,
      _ref$dateRangePopover = _ref.dateRangePopoverProps,
      dateRangePopoverProps = _ref$dateRangePopover === void 0 ? {} : _ref$dateRangePopover,
      others = _objectWithoutProperties(_ref, _excluded);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      rangeVisible = _useState2[0],
      setRangeVisible = _useState2[1];

  var inputTextRef = useRef(null);
  useImperativeHandle(ref, function () {
    return inputTextRef.current;
  }); // 类型修改

  type = type.replace('-range-popover', ''); // 开始和结束时间

  var start = null;
  var end = null;

  if (Array.isArray(value) && value.length === 2) {
    start = value[0];
    end = value[1];
  }

  var displayValue = ''; // 允许仅选中开始或者结束

  if ((start || end) && (typeof start === 'string' || typeof end === 'string')) {
    displayValue = "".concat(start || '').concat(rangeProps.separator || '~').concat(end || '');
  }

  if (start && end && typeof start === 'string' && typeof end === 'string') {
    displayValue = helper.getDateName(start, end);
  } // 点击文本框


  function handleClickInput() {
    if (onClick) onClick.apply(void 0, arguments);
    if (others.readOnly) return;
    setRangeVisible(true);
  } // 开始时间和结束时间


  function handleChange(e, value) {
    setRangeVisible(false);
    if (inputTextRef.current) e.currentTarget = inputTextRef.current;

    if (onChange) {
      onChange(e, value);
    }
  }

  return /*#__PURE__*/React.createElement(Fragment, null, children && /*#__PURE__*/React.createElement("div", _extends({
    ref: inputTextRef
  }, others, {
    onClick: handleClickInput
  }), children), !children && /*#__PURE__*/React.createElement(InputText, _extends({
    ref: inputTextRef
  }, others, {
    value: displayValue,
    type: "text",
    readOnly: true,
    onClick: handleClickInput
  })), /*#__PURE__*/React.createElement(DateRangePopover, _extends({}, dateRangePopoverProps, {
    caption: rangeProps.caption,
    show: rangeVisible,
    startInputDateProps: startInputDateProps,
    endInputDateProps: endInputDateProps,
    value: value,
    onChange: handleChange,
    onVisibleChange: setRangeVisible
  })));
});
export default InputDateRange;
